<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Přesunout vlevo</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Přesunout vpravo</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Odstranit z rychlého spuštění</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Problém s upuštěním</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Soubor/URL &apos;%1&apos; nyní nelze vložit do rychlého spuštění</translation>
    </message>
</context>
</TS>